# Friendly Words

This package returns curated lists of friendly words, as used in project names and elsewhere on glitch.com

> This is a Python port of Glitch's original JavaScript package [friendlyWords](https://github.com/glitchdotcom/friendly-words/#friendly-words)

## Usage

```python
import friendlywords

friendlywords.collections
# {'accrual', 'aggregation', 'album', 'analects', ...}
friendlywords.objects
# {'gargoyleosaurus', 'hydrangea', 'columnist', ...}
friendlywords.predicates
# {"warp", "windy", "paper", "shrouded", ...}
friendlywords.teams
# {'aerie', 'alliance', 'assembly', 'bale', ...}
```
